@@ -16,15 +16,16 @@
 #include "connectionmanager.h"
 #include "server.h"
 #include "preferences.h"
+#include "trayicon.h"
 
 #include <KActionCollection>
-//FIXME: Change to pretty <KIdleTime> include when KDE_IS_VERSION(4, 5, 0)
-#include <kidletime.h>
+#include <QIcon>
+#include <KIdleTime>
 #include <KToggleAction>
 
 AwayManager::AwayManager(QObject* parent) : QObject(parent)
 {
-    m_connectionManager = static_cast<Application*>(kapp)->getConnectionManager();
+    m_connectionManager = Application::instance()->getConnectionManager();
 
     connect(KIdleTime::instance(), SIGNAL(resumingFromIdle()), this, SLOT(resumeFromIdle()));
     connect(KIdleTime::instance(), SIGNAL(timeoutReached(int)), this, SLOT(idleTimeoutReached(int)));
@@ -163,8 +164,9 @@ void AwayManager::updateGlobalAwayAction(bool away)
     if (!away)
         simulateUserActivity();
 
-    Application* konvApp = static_cast<Application*>(kapp);
-    KToggleAction* awayAction = qobject_cast<KToggleAction*>(konvApp->getMainWindow()->actionCollection()->action("toggle_away"));
+    Application* konvApp = Application::instance();
+    KToggleAction* awayAction = qobject_cast<KToggleAction*>(konvApp->getMainWindow()->actionCollection()->action(QStringLiteral("toggle_away")));
+    Konversation::TrayIcon* trayIcon = konvApp->getMainWindow()->systemTrayIcon();
 
     if (!awayAction)
         return;
@@ -183,13 +185,15 @@ void AwayManager::updateGlobalAwayAction(bool away)
         if (awayCount == serverList.count())
         {
             awayAction->setChecked(true);
-            awayAction->setIcon(KIcon("im-user-away"));
+            awayAction->setIcon(QIcon::fromTheme(QStringLiteral("im-user-away")));
+            if (trayIcon) trayIcon->setAway(true);
         }
     }
     else
     {
         awayAction->setChecked(false);
-        awayAction->setIcon(KIcon("im-user"));
+        awayAction->setIcon(QIcon::fromTheme(QStringLiteral("im-suser")));
+        if (trayIcon) trayIcon->setAway(false);
     }
 }
 
@@ -217,7 +221,7 @@ void AwayManager::implementUpdateIdleTimeout(int identityId)
         implementMarkIdentityAway(identityId);
 
         // Since the user is away right now the next auto-away should occur
-        // in X minutes (where X is the the timeout which the user has
+        // in X minutes (where X is the timeout which the user has
         // configured for the identity).
         remainingTime = m_identitiesWithIdleTimesOnAutoAway[identityId];
     }
@@ -347,4 +351,4 @@ void AwayManager::identityOnAutoAwayWentOffline(int identityId)
     implementRemoveIdleTimeout(timerId);
 }
 
-#include "awaymanager.moc"
+
