@@ -18,31 +18,27 @@
 #include <QHeaderView>
 
 
-Ignore_Config::Ignore_Config( QWidget* parent, const char* name, Qt::WFlags fl )
+Ignore_Config::Ignore_Config( QWidget* parent, const char* name, Qt::WindowFlags fl )
     : QWidget( parent, fl )
 {
     setObjectName(QString::fromLatin1(name));
     setupUi(this);
 
-    connect(newButton,SIGNAL(clicked()),
-        this,SLOT(newIgnore()));
-    connect(removeButton,SIGNAL(clicked()),
-        this,SLOT(removeIgnore()));
-    connect(removeAllButton,SIGNAL(clicked()),
-	this,SLOT(removeAllIgnore()));
-    connect(ignoreListView, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
-        this,SLOT(select(QTreeWidgetItem*)));
-    connect(chkChannel, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(chkQuery, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(chkNotice, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(chkCTCP, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(chkDCC, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(chkInvite, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
-    connect(txtPattern, SIGNAL(textChanged(QString)), this, SLOT(flagCheckboxChanged()));
+    connect(newButton, &QPushButton::clicked, this, &Ignore_Config::newIgnore);
+    connect(removeButton, &QPushButton::clicked, this, &Ignore_Config::removeIgnore);
+    connect(removeAllButton, &QPushButton::clicked, this, &Ignore_Config::removeAllIgnore);
+    connect(ignoreListView, &QTreeWidget::currentItemChanged, this, &Ignore_Config::select);
+    connect(chkChannel, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(chkQuery, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(chkNotice, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(chkCTCP, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(chkDCC, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(chkInvite, &QCheckBox::clicked, this, &Ignore_Config::flagCheckboxChanged);
+    connect(txtPattern, &KLineEdit::textChanged, this, &Ignore_Config::flagCheckboxChanged);
 //    connect(chkException, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
     loadSettings();
 
-    ignoreListView->header()->setMovable(false);
+    ignoreListView->header()->setSectionsMovable(false);
 }
 
 Ignore_Config::~Ignore_Config()
@@ -211,4 +207,4 @@ void Ignore_Config::languageChange()
   loadSettings();
 }
 
-#include "ignore_config.moc"
+
