@@ -16,7 +16,7 @@
 
 #include <QScrollArea>
 
-#include "kdebug.h"
+#include "qdebug.h"
 
 namespace Konversation
 {
@@ -37,47 +37,30 @@ namespace Konversation
             layout->addWidget(area);
             setLayout(layout);
 
-            connect(m_toolbar, SIGNAL(toolChanged(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)),
-                    m_paintArea, SLOT(setTool(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool)));
+            connect(m_toolbar, &WhiteBoardToolBar::toolChanged, m_paintArea, &WhiteBoardPaintArea::setTool);
 
-            connect(m_toolbar, SIGNAL(foregroundColorChanged(QColor)),
-                    m_paintArea, SLOT(setForegroundColor(QColor)));
-            connect(m_toolbar, SIGNAL(backgroundColorChanged(QColor)),
-                    m_paintArea, SLOT(setBackgroundColor(QColor)));
-            connect(m_toolbar, SIGNAL(colorsSwapped(QColor,QColor)),
-                    m_paintArea, SLOT(swapColors(QColor,QColor)));
-            connect(m_toolbar, SIGNAL(fontChanged(QFont)),
-                    m_paintArea, SLOT(setFont(QFont)));
+            connect(m_toolbar, &WhiteBoardToolBar::foregroundColorChanged, m_paintArea, &WhiteBoardPaintArea::setForegroundColor);
+            connect(m_toolbar, &WhiteBoardToolBar::backgroundColorChanged, m_paintArea, &WhiteBoardPaintArea::setBackgroundColor);
+            connect(m_toolbar, &WhiteBoardToolBar::colorsSwapped, m_paintArea, &WhiteBoardPaintArea::swapColors);
+            connect(m_toolbar, &WhiteBoardToolBar::fontChanged, m_paintArea, &WhiteBoardPaintArea::setFont);
 
-            connect(m_toolbar, SIGNAL(clear()), this, SLOT(clear()));
-            connect(m_toolbar, SIGNAL(save(QString)), m_paintArea, SLOT(save(QString)));
-            connect(m_toolbar, SIGNAL(lineWidthChanged(int)), m_paintArea, SLOT(setPenWidth(int)));
+            connect(m_toolbar, &WhiteBoardToolBar::clear, this, &WhiteBoard::clear);
+            connect(m_toolbar, &WhiteBoardToolBar::save, m_paintArea, &WhiteBoardPaintArea::save);
+            connect(m_toolbar, &WhiteBoardToolBar::lineWidthChanged, m_paintArea, &WhiteBoardPaintArea::setPenWidth);
 
-            connect(m_paintArea, SIGNAL(drawedPencil(int,QColor,QColor,int,int,int,int)),
-                    this, SLOT(drawedPencil(int,QColor,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedLine(int,QColor,QColor,int,int,int,int)),
-                    this, SLOT(drawedLine(int,QColor,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedRectangle(int,QColor,int,int,int,int)),
-                    this, SLOT(drawedRectangle(int,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedFilledRectangle(int,QColor,QColor,int,int,int,int)),
-                    this, SLOT(drawedFilledRectangle(int,QColor,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedEllipse(int,QColor,int,int,int,int)),
-                    this, SLOT(drawedEllipse(int,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedFilledEllipse(int,QColor,QColor,int,int,int,int)),
-                    this, SLOT(drawedFilledEllipse(int,QColor,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(drawedArrow(int,QColor,int,int,int,int)),
-                    this, SLOT(drawedArrow(int,QColor,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(usedEraser(int,int,int,int,int)),
-                    this, SLOT(usedEraser(int,int,int,int,int)));
-            connect(m_paintArea, SIGNAL(usedFloodFill(int,int,QColor)),
-                    this, SLOT(usedFloodFill(int,int,QColor)));
-            connect(m_paintArea, SIGNAL(usedText(int,int,QString)),
-                    this, SLOT(usedText(int,int,QString)));
-            connect(m_paintArea, SIGNAL(usedTextExtended(int,int,QFont,QColor,QColor,QString)),
-                    this, SLOT(usedTextExtended(int,int,QFont,QColor,QColor,QString)));
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedPencil, this, &WhiteBoard::drawedPencil);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedLine, this, &WhiteBoard::drawedLine);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedRectangle, this, &WhiteBoard::drawedRectangle);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedFilledRectangle, this, &WhiteBoard::drawedFilledRectangle);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedEllipse, this, &WhiteBoard::drawedEllipse);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedFilledEllipse, this, &WhiteBoard::drawedFilledEllipse);
+            connect(m_paintArea, &WhiteBoardPaintArea::drawedArrow, this, &WhiteBoard::drawedArrow);
+            connect(m_paintArea, &WhiteBoardPaintArea::usedEraser, this, &WhiteBoard::usedEraser);
+            connect(m_paintArea, &WhiteBoardPaintArea::usedFloodFill, this, &WhiteBoard::usedFloodFill);
+            connect(m_paintArea, &WhiteBoardPaintArea::usedText, this, &WhiteBoard::usedText);
+            connect(m_paintArea, &WhiteBoardPaintArea::usedTextExtended, this, &WhiteBoard::usedTextExtended);
 
-            connect(m_paintArea, SIGNAL(colorPicked(QColor)),
-                    m_toolbar, SLOT(setForegroundColor(QColor)));
+            connect(m_paintArea, &WhiteBoardPaintArea::colorPicked, m_toolbar, &WhiteBoardToolBar::setForegroundColor);
         }
 
         WhiteBoard::~WhiteBoard()
@@ -92,7 +75,7 @@ namespace Konversation
 
         void WhiteBoard::receivedWhiteBoardLine(const QString& line)
         {
-            // kDebug() << line;
+            // qDebug() << line;
             if (line.isEmpty() || !line.contains(' '))
                 return;
 
@@ -105,8 +88,8 @@ namespace Konversation
                 return;
 
             const QString ctcpCommand(firstSplit.at(0));
-            // kDebug() << "ctcpCommand" << ctcpCommand;
-            // kDebug() << "firstSize" << firstSplit.size();
+            // qDebug() << "ctcpCommand" << ctcpCommand;
+            // qDebug() << "firstSize" << firstSplit.size();
 
             if (ctcpCommand == "DR" && firstSplit.size() == 2)
             {
@@ -114,7 +97,7 @@ namespace Konversation
                 const QStringList drArgsList = firstSplit.at(1).split(',', QString::SkipEmptyParts);
                 if (drArgsList.size() != 8)
                 {
-                    kDebug() << "wrong size:" << drArgsList.size();
+                    qDebug() << "wrong size:" << drArgsList.size();
                     return;
                 }
 
@@ -123,7 +106,7 @@ namespace Konversation
                 int toolType = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse tooltype:" << tmp;
+                    qDebug() << "unabled to parse tooltype:" << tmp;
                     return;
                 }
 
@@ -131,21 +114,21 @@ namespace Konversation
                 int lineWidth = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse linewidth:" << tmp;
+                    qDebug() << "unabled to parse linewidth:" << tmp;
                     return;
                 }
 
                 QColor penColor = parseColor(drArgsList.at(2), &ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse pencolor:" << drArgsList.at(2);
+                    qDebug() << "unabled to parse pencolor:" << drArgsList.at(2);
                     return;
                 }
 
                 QColor brushColor = parseColor(drArgsList.at(3), &ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse brush:" << drArgsList.at(3);
+                    qDebug() << "unabled to parse brush:" << drArgsList.at(3);
                     return;
                 }
 
@@ -153,7 +136,7 @@ namespace Konversation
                 int xFrom = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse xFrom:" << tmp;
+                    qDebug() << "unabled to parse xFrom:" << tmp;
                     return;
                 }
 
@@ -161,7 +144,7 @@ namespace Konversation
                 int yFrom = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse yFrom:" << tmp;
+                    qDebug() << "unabled to parse yFrom:" << tmp;
                     return;
                 }
 
@@ -169,7 +152,7 @@ namespace Konversation
                 int xTo = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse xTo:" << tmp;
+                    qDebug() << "unabled to parse xTo:" << tmp;
                     return;
                 }
 
@@ -177,7 +160,7 @@ namespace Konversation
                 int yTo = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "unabled to parse yTo:" << tmp;
+                    qDebug() << "unabled to parse yTo:" << tmp;
                     return;
                 }
 
@@ -191,35 +174,35 @@ namespace Konversation
                 {
                 case WhiteBoardGlobals::Line:
                 case WhiteBoardGlobals::Pencil:
-                    // kDebug() << "drawing a line" << lineWidth << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a line" << lineWidth << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawLine(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Rectangle:
-                    // kDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawRectangle(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FilledRectangle:
-                    // kDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawFilledRectangle(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Ellipse:
-                    // kDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a rectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawEllipse(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FilledEllipse:
-                    // kDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a filledrectangle" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->drawFilledEllipse(lineWidth, penColor, brushColor, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::Eraser:
-                    // kDebug() << "drawing a Eraser" << xFrom << yFrom << xTo << yTo;
+                    // qDebug() << "drawing a Eraser" << xFrom << yFrom << xTo << yTo;
                     m_paintArea->useEraser(lineWidth, xFrom, yFrom, xTo, yTo);
                     break;
                 case WhiteBoardGlobals::FloodFill:
-                    // kDebug() << "drawing a FloodFill" << xFrom << yFrom;
+                    // qDebug() << "drawing a FloodFill" << xFrom << yFrom;
                     m_paintArea->useFloodFill(xFrom, yFrom, penColor);
                     break;
                 case WhiteBoardGlobals::Arrow:
-                    // kDebug() << "drawing an Arrow" << xFrom << yFrom;
+                    // qDebug() << "drawing an Arrow" << xFrom << yFrom;
                     m_paintArea->drawArrow(lineWidth, penColor, xFrom, yFrom, xTo, yTo);
                     break;
                 }
@@ -229,7 +212,7 @@ namespace Konversation
                 QStringList txtArgsList = firstSplit.at(1).split(',', QString::KeepEmptyParts);
                 if (txtArgsList.size() < 3)
                 {
-                    kDebug() << "txt wrong size:" << txtArgsList.size();
+                    qDebug() << "txt wrong size:" << txtArgsList.size();
                     return;
                 }
 
@@ -238,7 +221,7 @@ namespace Konversation
                 int x1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txt unabled to parse x1:" << tmp;
+                    qDebug() << "txt unabled to parse x1:" << tmp;
                     return;
                 }
 
@@ -246,7 +229,7 @@ namespace Konversation
                 int y1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txt unabled to parse y1:" << tmp;
+                    qDebug() << "txt unabled to parse y1:" << tmp;
                     return;
                 }
 
@@ -261,7 +244,7 @@ namespace Konversation
                 QStringList txtArgsList = firstSplit.at(1).split(',', QString::KeepEmptyParts);
                 if (txtArgsList.size() < 8)
                 {
-                    kDebug() << "txtex wrong size:" << txtArgsList.size();
+                    qDebug() << "txtex wrong size:" << txtArgsList.size();
                     return;
                 }
 
@@ -270,7 +253,7 @@ namespace Konversation
                 int x1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse x1:" << tmp;
+                    qDebug() << "txtex unabled to parse x1:" << tmp;
                     return;
                 }
 
@@ -278,7 +261,7 @@ namespace Konversation
                 int y1 = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse y1:" << tmp;
+                    qDebug() << "txtex unabled to parse y1:" << tmp;
                     return;
                 }
 
@@ -288,7 +271,7 @@ namespace Konversation
                 int fontSize = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse fontsize:" << tmp;
+                    qDebug() << "txtex unabled to parse fontsize:" << tmp;
                     return;
                 }
 
@@ -296,21 +279,21 @@ namespace Konversation
                 int fontStyle = tmp.toInt(&ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse fontstyle:" << tmp;
+                    qDebug() << "txtex unabled to parse fontstyle:" << tmp;
                     return;
                 }
 
                 QColor penColor = parseColor(txtArgsList.at(5), &ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse pencolor:" << txtArgsList.at(5);
+                    qDebug() << "txtex unabled to parse pencolor:" << txtArgsList.at(5);
                     return;
                 }
 
                 QColor brushColor = parseColor(txtArgsList.at(6), &ok);
                 if (!ok)
                 {
-                    kDebug() << "txtex unabled to parse brush:" << txtArgsList.at(6);
+                    qDebug() << "txtex unabled to parse brush:" << txtArgsList.at(6);
                     return;
                 }
 
@@ -335,7 +318,7 @@ namespace Konversation
                 txtArgsList.removeFirst(); // textcolor
                 txtArgsList.removeFirst(); // bgcolor
                 QString text(txtArgsList.join(","));
-                // kDebug() << "TXTEX" << text << fontSize << fontName;
+                // qDebug() << "TXTEX" << text << fontSize << fontName;
                 m_paintArea->useTextExtended(x1,y1,tFont,penColor,brushColor,text);
             }
             else if (ctcpCommand == "CLS" && firstSplit.size() == 1)
@@ -359,7 +342,7 @@ namespace Konversation
                     m_toolbar->setSupportedTextType(WhiteBoardToolBar::ExtentedText);
                     return;
                 }
-                kDebug() << "unhandled CAN" << firstSplit.at(1);
+                qDebug() << "unhandled CAN" << firstSplit.at(1);
             }
             else if (ctcpCommand == "CANT" && firstSplit.size() == 2)
             {
@@ -370,7 +353,7 @@ namespace Konversation
                     m_toolbar->setSupportedTextType(WhiteBoardToolBar::SimpleText);
                     return;
                 }
-                kDebug() << "unhandled CANT" << firstSplit.at(1);
+                qDebug() << "unhandled CANT" << firstSplit.at(1);
             }
             else if (ctcpCommand == "DO" && firstSplit.size() == 2)
             {
@@ -388,7 +371,7 @@ namespace Konversation
                 const QStringList drArgsList = firstSplit.at(1).split(',', QString::SkipEmptyParts);
                 if (drArgsList.size() != 6)
                 {
-                    kDebug() << "blt wrong size:" << drArgsList.size();
+                    qDebug() << "blt wrong size:" << drArgsList.size();
                     return;
                 }
 
@@ -409,13 +392,13 @@ namespace Konversation
 
                 if (!finalOk)
                 {
-                    kDebug() << "blt unabled to parse coords:" << firstSplit.at(1);
+                    qDebug() << "blt unabled to parse coords:" << firstSplit.at(1);
                     return;
                 }
 
                 if (x2src <= x1src || y2src <= y1src)
                 {
-                    kDebug() << "blt coords invalid:" << firstSplit.at(1);
+                    qDebug() << "blt coords invalid:" << firstSplit.at(1);
                     return;
                 }
                 m_paintArea->useBlt(x1src, y1src, x2src, y2src, xdest, ydest);
@@ -424,7 +407,7 @@ namespace Konversation
 
         void WhiteBoard::clear()
         {
-            kDebug();
+            qDebug();
             m_paintArea->clear();
             static const QString cls = QString("\x01""CLS\x01");
             emit rawWhiteBoardCommand(cls);
@@ -567,7 +550,7 @@ namespace Konversation
             drLineCommand = drLineCommand.arg(tool).arg(
                                           lineWidth).arg(colorToString(penColor)).arg(colorToString(brushColor)).arg(
                                           xFrom).arg(yFrom).arg(xTo).arg(yTo);
-            // kDebug() << drLineCommand;
+            // qDebug() << drLineCommand;
             emit rawWhiteBoardCommand(drLineCommand);
         }
 
