@@ -32,17 +32,14 @@
 #include <QTimer>
 #include <QToolButton>
 #include <QHeaderView>
+#include <QInputDialog>
 
 #include <KLineEdit>
-#include <KInputDialog>
 #include <KPasswordDialog>
 #include <KMessageBox>
 #include <KIconLoader>
-#include <KVBox>
-#include <KHBox>
 #include <KComboBox>
 
-
 #define DELAYED_SORT_TRIGGER    10
 
 using namespace Konversation;
@@ -83,7 +80,6 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     nicks = 0;
     ops = 0;
     completionPosition = 0;
-    nickChangeDialog = 0;
     m_nicknameListViewTextChanged = 0;
 
     m_joined = false;
@@ -102,6 +98,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     channelSplitterHidden = false;
 
     setType(ChatWindow::Channel);
+    m_isTopLevelView = false;
 
     setChannelEncodingSupported(true);
 
@@ -112,7 +109,6 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     QSizePolicy greedy = QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
     m_vertSplitter = new QSplitter(Qt::Vertical, this);
-    m_vertSplitter->setOpaqueResize(KGlobalSettings::opaqueResize());
 
 
     QWidget* topicWidget = new QWidget(m_vertSplitter);
@@ -123,7 +119,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     topicLayout->setSpacing(0);
 
     m_topicButton = new QToolButton(topicWidget);
-    m_topicButton->setIcon(KIcon("document-edit"));
+    m_topicButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     m_topicButton->setToolTip(i18n("Edit Channel Settings"));
     m_topicButton->setAutoRaise(true);
     connect(m_topicButton, SIGNAL(clicked()), this, SLOT(showOptionsDialog()));
@@ -143,17 +139,27 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     topicLayout->addWidget(topicLine, 0, 1, -1, 1);
 
     // The box holding the channel modes
-    modeBox = new KHBox(topicWidget);
+    modeBox = new QFrame(topicWidget);
+    QHBoxLayout* modeBoxLayout = new QHBoxLayout(modeBox);
+    modeBoxLayout->setMargin(0);
     modeBox->hide();
     modeBox->setSizePolicy(hfixed);
-    modeT = new ModeButton("T",modeBox,0);
-    modeN = new ModeButton("N",modeBox,1);
-    modeS = new ModeButton("S",modeBox,2);
-    modeI = new ModeButton("I",modeBox,3);
-    modeP = new ModeButton("P",modeBox,4);
-    modeM = new ModeButton("M",modeBox,5);
-    modeK = new ModeButton("K",modeBox,6);
-    modeL = new ModeButton("L",modeBox,7);
+    modeT = new ModeButton(QStringLiteral("T"),modeBox,0);
+    modeBoxLayout->addWidget(modeT);
+    modeN = new ModeButton(QStringLiteral("N"),modeBox,1);
+    modeBoxLayout->addWidget(modeN);
+    modeS = new ModeButton(QStringLiteral("S"),modeBox,2);
+    modeBoxLayout->addWidget(modeS);
+    modeI = new ModeButton(QStringLiteral("I"),modeBox,3);
+    modeBoxLayout->addWidget(modeI);
+    modeP = new ModeButton(QStringLiteral("P"),modeBox,4);
+    modeBoxLayout->addWidget(modeP);
+    modeM = new ModeButton(QStringLiteral("M"),modeBox,5);
+    modeBoxLayout->addWidget(modeM);
+    modeK = new ModeButton(QStringLiteral("K"),modeBox,6);
+    modeBoxLayout->addWidget(modeK);
+    modeL = new ModeButton(QStringLiteral("L"),modeBox,7);
+    modeBoxLayout->addWidget(modeL);
 
     modeT->setWhatsThis(ChannelOptionsDialog::whatsThisForMode('T'));
     modeN->setWhatsThis(ChannelOptionsDialog::whatsThisForMode('N'));
@@ -174,6 +180,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     connect(modeL,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
 
     limit=new KLineEdit(modeBox);
+    modeBoxLayout->addWidget(limit);
     limit->setToolTip(i18n("Maximum users allowed in channel"));
     limit->setWhatsThis(i18n("<qt><p>This is the channel user limit - the maximum number of users that can be in the channel at a time.  If you are an operator, you can set this.  The channel mode <b>T</b>opic (button to left) will automatically be set if set this.</p></qt>"));
     connect(limit,SIGNAL (returnPressed()),this,SLOT (channelLimitChanged()) );
@@ -189,7 +196,6 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     // (this) The main Box, holding the channel view/topic and the input line
     m_horizSplitter = new QSplitter(m_vertSplitter);
     m_vertSplitter->setStretchFactor(m_vertSplitter->indexOf(m_horizSplitter), 1);
-    m_horizSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
 
     // Server will be set later in setServer()
     IRCViewBox* ircViewBox = new IRCViewBox(m_horizSplitter);
@@ -198,19 +204,25 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     ircViewBox->ircView()->setContextMenuOptions(IrcContextMenus::ShowChannelActions, true);
 
     // The box that holds the Nick List and the quick action buttons
-    nickListButtons = new KVBox(m_horizSplitter);
+    nickListButtons = new QFrame(m_horizSplitter);
     m_horizSplitter->setStretchFactor(m_horizSplitter->indexOf(nickListButtons), 0);
-    nickListButtons->setSpacing(spacing());
+    QVBoxLayout* nickListButtonsLayout = new QVBoxLayout(nickListButtons);
+    nickListButtonsLayout->setSpacing(spacing());
+    nickListButtonsLayout->setMargin(0);
 
     nicknameListView=new NickListView(nickListButtons, this);
+    nickListButtons->layout()->addWidget(nicknameListView);
     nicknameListView->installEventFilter(this);
 
     // initialize buttons grid, will be set up in updateQuickButtons
     m_buttonsGrid = 0;
 
     // The box holding the Nickname button and Channel input
-    commandLineBox = new KHBox(this);
-    commandLineBox->setSpacing(spacing());
+    commandLineBox = new QFrame(this);
+    QHBoxLayout* commandLineLayout = new QHBoxLayout(commandLineBox);
+    commandLineBox->setLayout(commandLineLayout);
+    commandLineLayout->setMargin(0);
+    commandLineLayout->setSpacing(spacing());
 
     nicknameCombobox = new KComboBox(commandLineBox);
     nicknameCombobox->setEditable(true);
@@ -223,9 +235,14 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     awayLabel->hide();
     cipherLabel = new QLabel(commandLineBox);
     cipherLabel->hide();
-    cipherLabel->setPixmap(KIconLoader::global()->loadIcon("document-encrypt", KIconLoader::Toolbar));
+    cipherLabel->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("document-encrypt"), KIconLoader::Toolbar));
     m_inputBar = new IRCInput(commandLineBox);
 
+    commandLineLayout->addWidget(nicknameCombobox);
+    commandLineLayout->addWidget(awayLabel);
+    commandLineLayout->addWidget(cipherLabel);
+    commandLineLayout->addWidget(m_inputBar);
+
     getTextView()->installEventFilter(m_inputBar);
     topicLine->installEventFilter(m_inputBar);
     m_inputBar->installEventFilter(this);
@@ -293,9 +310,6 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     #ifdef HAVE_QCA2
     m_cipher = 0;
     #endif
-    //FIXME JOHNFLUX
-    // connect( Konversation::Addressbook::self()->getAddressBook(), SIGNAL(addressBookChanged(AddressBook*)), this, SLOT(slotLoadAddressees()) );
-    // connect( Konversation::Addressbook::self(), SIGNAL(addresseesChanged()), this, SLOT(slotLoadAddressees()));
 
     // Setup delayed sort timer
     m_delayedSortTimer = new QTimer(this);
@@ -376,15 +390,15 @@ void Channel::setEncryptedOutput(bool e)
 
 Channel::~Channel()
 {
-    kDebug() << "(" << getName() << ")";
+    qDebug() << "(" << getName() << ")";
 
     // Purge nickname list
     purgeNicks();
-    kDebug() << "Nicks purged.";
+    qDebug() << "Nicks purged.";
 
     // Unlink this channel from channel list
     m_server->removeChannel(this);
-    kDebug() << "Channel removed.";
+    qDebug() << "Channel removed.";
 
     if (m_recreationScheduled)
     {
@@ -452,7 +466,7 @@ void Channel::textPasted(const QString& text)
 {
     if(m_server)
     {
-        QStringList multiline = text.split('\n', QString::SkipEmptyParts);
+        QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
         for(int index=0;index<multiline.count();index++)
         {
             QString line=multiline[index];
@@ -516,7 +530,7 @@ void Channel::completeNick()
         // remember old cursor position locally
         oldPos = pos;
         // step back to last space or start of line
-        while(pos && line[pos-1] != ' ') pos--;
+        while(pos && line[pos-1] != QLatin1Char(' ')) pos--;
         // copy search pattern (lowercase)
         QString pattern = line.mid(pos, oldPos - pos);
         // copy line to newLine-buffer
@@ -541,7 +555,7 @@ void Channel::completeNick()
                 {
                     if(Preferences::self()->nickCompletionMode() == 1)
                     {
-                        QString nicksFound = found.join(" ");
+                        QString nicksFound = found.join(QStringLiteral(" "));
                         appendServerMessage(i18n("Completion"), i18n("Possible completions: %1.", nicksFound));
                     }
                     else
@@ -726,7 +740,7 @@ QString Channel::getPassword()
 
     for (QStringList::const_iterator it = m_modeList.constBegin(); it != m_modeList.constEnd(); ++it)
     {
-        if ((*it)[0] == 'k') password = (*it).mid(1);
+        if ((*it)[0] == QLatin1Char('k')) password = (*it).mid(1);
     }
 
     if (password.isEmpty() && m_server->getServerGroup())
@@ -793,7 +807,7 @@ void Channel::sendText(const QString& sendLine)
     m_server->getOutputFilter()->replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-    QStringList outList = outputAll.split(QRegExp("[\r\n]+"), QString::SkipEmptyParts);
+    QStringList outList = outputAll.split(QRegExp(QStringLiteral("[\r\n]+")), QString::SkipEmptyParts);
     for(int index=0;index<outList.count();index++)
     {
         QString output(outList[index]);
@@ -867,7 +881,7 @@ void Channel::channelLimitChanged()
 void Channel::modeButtonClicked(int id, bool on)
 {
     char mode[]={'t','n','s','i','p','m','k','l'};
-    QString command("MODE %1 %2%3 %4");
+    QString command(QStringLiteral("MODE %1 %2%3 %4"));
     QString args = getPassword();
 
     if (mode[id] == 'k')
@@ -890,11 +904,11 @@ void Channel::modeButtonClicked(int id, bool on)
         {
             bool ok=false;
             // ask user how many nicks should be the limit
-            args=KInputDialog::getText(i18n("Channel User Limit"),
+            args=QInputDialog::getText(this, i18n("Channel User Limit"),
                 i18n("Enter the new user limit for the channel:"),
+                QLineEdit::Normal,
                 limit->text(),                    // will be always "" but what the hell ;)
-                &ok,
-                this);
+                &ok);
             // leave this function if user cancels
             if(!ok) return;
         }
@@ -902,7 +916,7 @@ void Channel::modeButtonClicked(int id, bool on)
             args=limit->text();
     }
     // put together the mode command and send it to the server queue
-    m_server->queue(command.arg(getName()).arg((on) ? "+" : "-").arg(mode[id]).arg(args));
+    m_server->queue(command.arg(getName()).arg((on) ? QStringLiteral("+") : QStringLiteral("-")).arg(mode[id]).arg(args));
 }
 
 void Channel::quickButtonClicked(const QString &buttonText)
@@ -911,7 +925,7 @@ void Channel::quickButtonClicked(const QString &buttonText)
     QString out=m_server->parseWildcards(buttonText,m_server->getNickname(),getName(),getPassword(),getSelectedNickList(), m_inputBar->toPlainText());
 
     // are there any newlines in the definition?
-    if (out.contains('\n'))
+    if (out.contains(QLatin1Char('\n')))
         sendText(out);
     // single line without newline needs to be copied into input line
     else
@@ -946,7 +960,7 @@ void Channel::addNickname(ChannelNickPtr channelnick)
         requestNickListSort();
     }
     else
-        kWarning() << "Nickname " << channelnick->getNickname() << " has not been added as it is already in the nickname list."<< endl;
+        qWarning() << "Nickname " << channelnick->getNickname() << " has not been added as it is already in the nickname list."<< endl;
 }
 
 // Use with caution! Does not check for duplicates or may not
@@ -1119,7 +1133,7 @@ void Channel::removeNick(ChannelNickPtr channelNick, const QString &reason, bool
     {
         // if the reason contains text markup characters, play it safe and reset all
         if (hasIRCMarkups(displayReason))
-            displayReason += "\017";
+            displayReason += QStringLiteral("\017");
     }
 
     if(channelNick->getNickname() == m_server->getNickname())
@@ -1189,7 +1203,7 @@ void Channel::removeNick(ChannelNickPtr channelNick, const QString &reason, bool
         }
         else
         {
-            kWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
+            qWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
         }
     }
 }
@@ -1207,7 +1221,7 @@ void Channel::kickNick(ChannelNickPtr channelNick, const QString &kicker, const
     {
         // if the reason contains text markup characters, play it safe and reset all
         if (hasIRCMarkups(displayReason))
-            displayReason += "\017";
+            displayReason += QStringLiteral("\017");
     }
 
     if(channelNick->getNickname() == m_server->getNickname())
@@ -1277,7 +1291,7 @@ void Channel::kickNick(ChannelNickPtr channelNick, const QString &kicker, const
 
         if(nick == 0)
         {
-            kWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
+            qWarning() << "Nickname " << channelNick->getNickname() << " not found!"<< endl;
         }
         else
         {
@@ -1331,7 +1345,7 @@ void Channel::adjustOps(int value)
 
 void Channel::emitUpdateInfo()
 {
-    QString info = getName() + " - ";
+    QString info = getName() + QStringLiteral(" - ");
     info += i18np("%1 nick", "%1 nicks", numberOfNicks());
     info += i18np(" (%1 op)", " (%1 ops)", numberOfOps());
 
@@ -1349,7 +1363,7 @@ void Channel::setTopic(const QString& text)
 
     // If the reason contains text markup characters, play it safe and reset all.
     if (!cleanTopic.isEmpty() && hasIRCMarkups(cleanTopic))
-        cleanTopic += "\017";
+        cleanTopic += QStringLiteral("\017");
 
     appendCommandMessage(i18n("Topic"), i18n("The channel topic is \"%1\".", cleanTopic));
 
@@ -1362,7 +1376,7 @@ void Channel::setTopic(const QString& nickname, const QString& text)
 
     // If the reason contains text markup characters, play it safe and reset all.
     if (!cleanTopic.isEmpty() && hasIRCMarkups(cleanTopic))
-        cleanTopic += "\017";
+        cleanTopic += QStringLiteral("\017");
 
     if (nickname == m_server->getNickname())
         appendCommandMessage(i18n("Topic"), i18n("You set the channel topic to \"%1\".", cleanTopic));
@@ -1398,7 +1412,7 @@ void Channel::updateMode(const QString& sourceNick, char mode, bool plus, const
     bool toMe = false;
 
     // HACK right now Server only keeps type A modes
-    bool banTypeThang = m_server->banAddressListModes().contains(QChar(mode));
+    bool banTypeThang = m_server->banAddressListModes().contains(QLatin1Char(mode));
 
     // remember if this nick had any type of op.
     bool wasAnyOp = false;
@@ -1775,28 +1789,28 @@ void Channel::updateMode(const QString& sourceNick, char mode, bool plus, const
         default:
         if (plus)
         {
-            if (Konversation::getChannelModesHash().contains(mode))
+            if (Konversation::getChannelModesHash().contains(QLatin1Char(mode)))
             {
-                if (fromMe) message = i18n("You set the channel mode '%1'.", Konversation::getChannelModesHash().value(mode));
-                else        message= i18n("%1 sets the channel mode '%2'.", sourceNick, Konversation::getChannelModesHash().value(mode));
+                if (fromMe) message = i18n("You set the channel mode '%1'.", Konversation::getChannelModesHash().value(QLatin1Char(mode)));
+                else        message= i18n("%1 sets the channel mode '%2'.", sourceNick, Konversation::getChannelModesHash().value(QLatin1Char(mode)));
             }
             else
             {
-                if (fromMe) message = i18n("You set channel mode +%1", QString(mode));
-                else        message = i18n("%1 sets channel mode +%2", sourceNick, QString(mode));
+                if (fromMe) message = i18n("You set channel mode +%1", QLatin1Char(mode));
+                else        message = i18n("%1 sets channel mode +%2", sourceNick, QLatin1Char(mode));
             }
         }
         else
         {
-            if (Konversation::getChannelModesHash().contains(mode))
+            if (Konversation::getChannelModesHash().contains(QLatin1Char(mode)))
             {
-                if (fromMe) message = i18n("You remove the channel mode '%1'.", Konversation::getChannelModesHash().value(mode));
-                else        message= i18n("%1 removes the channel mode '%2'.", sourceNick, Konversation::getChannelModesHash().value(mode));
+                if (fromMe) message = i18n("You remove the channel mode '%1'.", Konversation::getChannelModesHash().value(QLatin1Char(mode)));
+                else        message= i18n("%1 removes the channel mode '%2'.", sourceNick, Konversation::getChannelModesHash().value(QLatin1Char(mode)));
             }
             else
             {
-                if (fromMe) message = i18n("You set channel mode -%1", QString(mode));
-                else        message = i18n("%1 sets channel mode -%2", sourceNick, QString(mode));
+                if (fromMe) message = i18n("You set channel mode -%1", QLatin1Char(mode));
+                else        message = i18n("%1 sets channel mode -%2", sourceNick, QLatin1Char(mode));
             }
         }
     }
@@ -1825,7 +1839,7 @@ void Channel::clearModeList()
     // Keep channel password in the backing store, for rejoins.
     for (QStringList::const_iterator it = m_modeList.constBegin(); it != m_modeList.constEnd(); ++it)
     {
-        if ((*it)[0] == 'k') k = (*it);
+        if ((*it)[0] == QLatin1Char('k')) k = (*it);
     }
 
     m_modeList.clear();
@@ -1883,11 +1897,11 @@ void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
 
     if(plus)
     {
-        m_modeList.append(QString(mode + parameter));
+        m_modeList.append(QString(QLatin1Char(mode) + parameter));
     }
     else
     {
-        QStringList removable = m_modeList.filter(QRegExp(QString("^%1.*").arg(mode)));
+        QStringList removable = m_modeList.filter(QRegExp(QString(QStringLiteral("^%1.*")).arg(mode)));
         foreach(const QString &mode, removable)
         {
             m_modeList.removeOne(mode);
@@ -1906,6 +1920,7 @@ void Channel::updateQuickButtons(const QStringList &newButtonList)
 
     // the grid that holds the quick action buttons
     m_buttonsGrid = new QWidget (nickListButtons); //Q3Grid(2, nickListButtons);
+    nickListButtons->layout()->addWidget(m_buttonsGrid);
     m_buttonsGrid->hide();
     QGridLayout* layout = new QGridLayout (m_buttonsGrid);
     layout->setMargin(0);
@@ -1927,17 +1942,17 @@ void Channel::updateQuickButtons(const QStringList &newButtonList)
         // Get the button definition
         QString buttonText=newButtonList[index];
         // Extract button label
-        QString buttonLabel=buttonText.section(',',0,0);
+        QString buttonLabel=buttonText.section(QLatin1Char(','),0,0);
         // Extract button definition
-        buttonText=buttonText.section(',',1);
+        buttonText=buttonText.section(QLatin1Char(','),1);
 
         quickButton->setText(buttonLabel);
         quickButton->setDefinition(buttonText);
 
         // Add tool tips
-        QString toolTip=buttonText.replace('&',"&amp;").
-            replace('<',"&lt;").
-            replace('>',"&gt;");
+        QString toolTip=buttonText.replace(QLatin1Char('&'),QStringLiteral("&amp;")).
+            replace(QLatin1Char('<'),QStringLiteral("&lt;")).
+            replace(QLatin1Char('>'),QStringLiteral("&gt;"));
 
         quickButton->setToolTip(toolTip);
 
@@ -2087,10 +2102,10 @@ void Channel::updateAppearance()
     }
     else
     {
-        topicLine->setFont(KGlobalSettings::generalFont());
-        m_inputBar->setFont(KGlobalSettings::generalFont());
-        nicknameCombobox->setFont(KGlobalSettings::generalFont());
-        limit->setFont(KGlobalSettings::generalFont());
+        topicLine->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
+        m_inputBar->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
+        nicknameCombobox->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
+        limit->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
     }
 
     nicknameListView->resort();
@@ -2100,7 +2115,7 @@ void Channel::updateAppearance()
     if (Preferences::self()->customListFont())
         nicknameListView->setFont(Preferences::self()->listFont());
     else
-        nicknameListView->setFont(KGlobalSettings::generalFont());
+        nicknameListView->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
 
     nicknameListView->refresh();
 
@@ -2138,7 +2153,7 @@ void Channel::nicknameComboboxChanged()
 void Channel::changeNickname(const QString& newNickname)
 {
     if (!newNickname.isEmpty())
-        m_server->queue("NICK "+newNickname);
+        m_server->queue(QStringLiteral("NICK ")+newNickname);
 }
 
 void Channel::queueNicks(const QStringList& nicknameList)
@@ -2220,7 +2235,7 @@ void Channel::autoUserhost()
         {
             if(nick->getChannelNick()->getHostmask().isEmpty())
             {
-                if(limit--) nickString = nickString + nick->getChannelNick()->getNickname() + ' ';
+                if(limit--) nickString = nickString + nick->getChannelNick()->getNickname() + QLatin1Char(' ');
                 else break;
             }
         }
@@ -2243,8 +2258,8 @@ void Channel::setAutoUserhost(bool state)
         // Cannot use QHeaderView::ResizeToContents here because it is slow
         // and it gets triggered by setSortingEnabled(). Using timed resize
         // instead, see Channel::autoUserhost() above.
-        nicknameListView->header()->setResizeMode(Nick::NicknameColumn, QHeaderView::Fixed);
-        nicknameListView->header()->setResizeMode(Nick::HostmaskColumn, QHeaderView::Fixed);
+        nicknameListView->header()->setSectionResizeMode(Nick::NicknameColumn, QHeaderView::Fixed);
+        nicknameListView->header()->setSectionResizeMode(Nick::HostmaskColumn, QHeaderView::Fixed);
         userhostTimer.start(10000);
         m_nicknameListViewTextChanged |= 0xFF; // ResizeColumnsToContents
         QTimer::singleShot(0, this, SLOT(autoUserhost())); // resize columns ASAP
@@ -2252,7 +2267,7 @@ void Channel::setAutoUserhost(bool state)
     else
     {
         nicknameListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-        nicknameListView->header()->setResizeMode(Nick::NicknameColumn, QHeaderView::Stretch);
+        nicknameListView->header()->setSectionResizeMode(Nick::NicknameColumn, QHeaderView::Stretch);
         userhostTimer.stop();
     }
 }
@@ -2377,7 +2392,7 @@ bool Channel::closeYourself(bool confirm)
             i18n("Leave Channel"),
             KGuiItem(i18n("Leave")),
             KStandardGuiItem::cancel(),
-            "QuitChannelTab");
+            QStringLiteral("QuitChannelTab"));
 
     if (result==KMessageBox::Continue)
     {
@@ -2597,7 +2612,7 @@ void Channel::repositionNick(Nick *nick)
         nicknameList.removeAt(index);
         fastAddNickname(nick->getChannelNick(), nick);
     } else {
-        kWarning() << "Nickname " << nick->getChannelNick()->getNickname() << " not found!"<< endl;
+        qWarning() << "Nickname " << nick->getChannelNick()->getNickname() << " not found!"<< endl;
     }
 }
 
@@ -2627,12 +2642,12 @@ void Channel::addBan(const QString& ban)
 {
     for ( QStringList::iterator it = m_BanList.begin(); it != m_BanList.end(); ++it )
     {
-        if ((*it).section(' ', 0, 0) == ban.section(' ', 0, 0))
+        if ((*it).section(QLatin1Char(' '), 0, 0) == ban.section(QLatin1Char(' '), 0, 0))
         {
             // Ban is already in list.
             it = m_BanList.erase(it);
 
-            emit banRemoved(ban.section(' ', 0, 0));
+            emit banRemoved(ban.section(QLatin1Char(' '), 0, 0));
             if (it == m_BanList.end())
                 break;
         }
@@ -2647,7 +2662,7 @@ void Channel::removeBan(const QString& ban)
 {
   foreach(const QString &string, m_BanList)
   {
-    if (string.section(' ', 0, 0) == ban)
+    if (string.section(QLatin1Char(' '), 0, 0) == ban)
     {
       m_BanList.removeOne(string);
 
@@ -2768,17 +2783,17 @@ NickList::NickList() : QList<Nick*>()
 }
 
 QString NickList::completeNick(const QString& pattern, bool& complete, QStringList& found,
-			       bool skipNonAlfaNum, bool caseSensitive)
+                   bool skipNonAlfaNum, bool caseSensitive)
 {
     found.clear();
-    QString prefix('^');
+    QString prefix(QLatin1Char('^'));
     QString newNick;
     QString prefixCharacter = Preferences::self()->prefixCharacter();
     NickList foundNicks;
 
-    if((pattern.contains(QRegExp("^(\\d|\\w)"))) && skipNonAlfaNum)
+    if((pattern.contains(QRegExp(QStringLiteral("^(\\d|\\w)")))) && skipNonAlfaNum)
     {
-        prefix = "^([^\\d\\w]|[\\_]){0,}";
+        prefix = QStringLiteral("^([^\\d\\w]|[\\_]){0,}");
     }
 
     QRegExp regexp(prefix + QRegExp::escape(pattern));
@@ -2849,7 +2864,7 @@ bool NickList::containsNick(const QString& nickname)
     return false;
 }
 
-#include "channel.moc"
+
 
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
 // vim: set et sw=4 ts=4 cino=l1,cs,U1:
