@@ -34,11 +34,11 @@ class OutputFilterResolveJob : public QObject
     Q_OBJECT
 
     public:
-        OutputFilterResolveJob(const Konversation::OutputFilterInput& input);
+        explicit OutputFilterResolveJob(const Konversation::OutputFilterInput& input);
         ~OutputFilterResolveJob();
 
 
-    private slots:
+    private Q_SLOTS:
         void resolved(QHostInfo hostInfo);
 
 
