@@ -73,21 +73,21 @@ class Query : public ChatWindow
         Konversation::Cipher* getCipher();
         #endif
 
-    signals:
+    Q_SIGNALS:
         void sendFile(const QString& recipient);
         void updateQueryChrome(ChatWindow*, const QString&);
 
-    public slots:
+    public Q_SLOTS:
         void sendText(const QString& text);
         virtual void indicateAway(bool show);
         void setEncryptedOutput(bool);
         void connectionStateChanged(Server*, Konversation::ConnectionState);
 
-    protected slots:
+    protected Q_SLOTS:
         void queryTextEntered();
         void queryPassthroughCommand();
         void sendFileMenu();
-        void urlsDropped(const KUrl::List urls);
+        void urlsDropped(const QList<QUrl>& urls);
         // connected to IRCInput::textPasted() - used to handle large/multiline pastes
         void textPasted(const QString& text);
         void nickInfoChanged();
@@ -108,8 +108,6 @@ class Query : public ChatWindow
 
         QSplitter* m_headerSplitter;
         KSqueezedTextLabel* queryHostmask;
-        QLabel* addresseeimage;
-        QLabel* addresseelogoimage;
         QLabel* blowfishLabel;
         AwayLabel* awayLabel;
         NickInfoPtr m_nickInfo;
