@@ -25,63 +25,78 @@
 #include <QCheckBox>
 
 #include <KMessageBox>
-#include <KPushButton>
+#include <QPushButton>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <KGuiItem>
+#include <QVBoxLayout>
 
 
 namespace Konversation
 {
 
     ServerGroupDialog::ServerGroupDialog(const QString& title, QWidget *parent)
-        : KDialog(parent)
+        : QDialog(parent)
     {
-        setCaption(title);
-        setButtons(Ok|Cancel);
+        setWindowTitle(title);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        QWidget *mainWidget = new QWidget(this);
+        QVBoxLayout *mainLayout = new QVBoxLayout;
+        setLayout(mainLayout);
+        mainLayout->addWidget(mainWidget);
+        QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+        okButton->setDefault(true);
+        okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &ServerGroupDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerGroupDialog::reject);
+        //PORTING SCRIPT: WARNING mainLayout->addWidget(buttonBox) must be last item in layout. Please move it.
+        mainLayout->addWidget(buttonBox);
 
         m_id = -1;
         m_identitiesNeedsUpdate = false;
         m_editedServer = false;
 
         m_mainWidget = new Ui::ServerGroupDialogUI();
-        m_mainWidget->setupUi(mainWidget());
-        mainWidget()->layout()->setMargin(0);
+        m_mainWidget->setupUi(mainWidget);
+        mainLayout->setMargin(0);
         m_mainWidget->serverWidget->layout()->setMargin(0);
         m_mainWidget->channelWidget->layout()->setMargin(0);
 
-        connect(m_mainWidget->m_editIdentityButton, SIGNAL(clicked()), this, SLOT(editIdentity()));
+        connect(m_mainWidget->m_editIdentityButton, &QPushButton::clicked, this, &ServerGroupDialog::editIdentity);
 
         IdentityList identities = Preferences::identityList();
 
         for (IdentityList::ConstIterator it = identities.constBegin(); it != identities.constEnd(); ++it)
             m_mainWidget->m_identityCBox->addItem((*it)->getName());
 
-        m_mainWidget->m_removeServerButton->setIcon(KIcon("list-remove"));
-        m_mainWidget->m_upServerBtn->setIcon(KIcon("arrow-up"));
-        m_mainWidget->m_downServerBtn->setIcon(KIcon("arrow-down"));
+        m_mainWidget->m_removeServerButton->setIcon(QIcon::fromTheme("list-remove"));
+        m_mainWidget->m_upServerBtn->setIcon(QIcon::fromTheme("arrow-up"));
+        m_mainWidget->m_downServerBtn->setIcon(QIcon::fromTheme("arrow-down"));
 
-        connect(m_mainWidget->m_addServerButton, SIGNAL(clicked()), this, SLOT(addServer()));
+        connect(m_mainWidget->m_addServerButton, &QPushButton::clicked, this, &ServerGroupDialog::addServer);
         connect(m_mainWidget->m_changeServerButton, SIGNAL(clicked()), this, SLOT(editServer()));
-        connect(m_mainWidget->m_removeServerButton, SIGNAL(clicked()), this, SLOT(deleteServer()));
-        connect(m_mainWidget->m_serverLBox, SIGNAL(itemSelectionChanged()), this, SLOT(updateServerArrows()));
-        connect(m_mainWidget->m_upServerBtn, SIGNAL(clicked()), this, SLOT(moveServerUp()));
-        connect(m_mainWidget->m_downServerBtn, SIGNAL(clicked()), this, SLOT(moveServerDown()));
+        connect(m_mainWidget->m_removeServerButton, &QToolButton::clicked, this, &ServerGroupDialog::deleteServer);
+        connect(m_mainWidget->m_serverLBox, &QListWidget::itemSelectionChanged, this, &ServerGroupDialog::updateServerArrows);
+        connect(m_mainWidget->m_upServerBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveServerUp);
+        connect(m_mainWidget->m_downServerBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveServerDown);
 
-        m_mainWidget->m_removeChannelButton->setIcon(KIcon("list-remove"));
-        m_mainWidget->m_upChannelBtn->setIcon(KIcon("arrow-up"));
-        m_mainWidget->m_downChannelBtn->setIcon(KIcon("arrow-down"));
+        m_mainWidget->m_removeChannelButton->setIcon(QIcon::fromTheme("list-remove"));
+        m_mainWidget->m_upChannelBtn->setIcon(QIcon::fromTheme("arrow-up"));
+        m_mainWidget->m_downChannelBtn->setIcon(QIcon::fromTheme("arrow-down"));
 
-        connect(m_mainWidget->m_addChannelButton, SIGNAL(clicked()), this, SLOT(addChannel()));
-        connect(m_mainWidget->m_changeChannelButton, SIGNAL(clicked()), this, SLOT(editChannel()));
-        connect(m_mainWidget->m_removeChannelButton, SIGNAL(clicked()), this, SLOT(deleteChannel()));
-        connect(m_mainWidget->m_channelLBox, SIGNAL(itemSelectionChanged()), this, SLOT(updateChannelArrows()));
-        connect(m_mainWidget->m_upChannelBtn, SIGNAL(clicked()), this, SLOT(moveChannelUp()));
-        connect(m_mainWidget->m_downChannelBtn, SIGNAL(clicked()), this, SLOT(moveChannelDown()));
+        connect(m_mainWidget->m_addChannelButton, &QPushButton::clicked, this, &ServerGroupDialog::addChannel);
+        connect(m_mainWidget->m_changeChannelButton, &QPushButton::clicked, this, &ServerGroupDialog::editChannel);
+        connect(m_mainWidget->m_removeChannelButton, &QToolButton::clicked, this, &ServerGroupDialog::deleteChannel);
+        connect(m_mainWidget->m_channelLBox, &QListWidget::itemSelectionChanged, this, &ServerGroupDialog::updateChannelArrows);
+        connect(m_mainWidget->m_upChannelBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveChannelUp);
+        connect(m_mainWidget->m_downChannelBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveChannelDown);
 
-        setButtonGuiItem(Ok, KGuiItem(i18n("&OK"), "dialog-ok", i18n("Change network information")));
-        setButtonGuiItem(Cancel, KGuiItem(i18n("&Cancel"), "dialog-cancel", i18n("Discards all changes made")));
+        KGuiItem::assign(okButton, KGuiItem(i18n("&OK"), "dialog-ok", i18n("Change network information")));
+        KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KGuiItem(i18n("&Cancel"), "dialog-cancel", i18n("Discards all changes made")));
 
         m_mainWidget->m_nameEdit->setFocus();
 
-        setInitialSize(QSize(320, 400));
+        resize(QSize(320, 400));
     }
 
     ServerGroupDialog::~ServerGroupDialog()
@@ -149,7 +164,7 @@ namespace Konversation
             return m_serverList[m_editedServerIndex];
         }
 
-        return ServerSettings("");
+        return ServerSettings(QString());
     }
 
     int ServerGroupDialog::execAndEditServer(ServerSettings server)
@@ -163,7 +178,7 @@ namespace Konversation
     {
         QPointer<ServerDialog> dlg = new ServerDialog(i18n("Add Server"), this);
 
-        if(dlg->exec() == KDialog::Accepted)
+        if(dlg->exec() == QDialog::Accepted)
         {
             ServerSettings server = dlg->serverSettings();
             m_mainWidget->m_serverLBox->addItem(server.host());
@@ -182,7 +197,7 @@ namespace Konversation
             QPointer <ServerDialog> dlg = new ServerDialog(i18n("Edit Server"), this);
             dlg->setServerSettings(m_serverList[current]);
 
-            if(dlg->exec() == KDialog::Accepted)
+            if(dlg->exec() == QDialog::Accepted)
             {
                 ServerSettings server = dlg->serverSettings();
                 m_mainWidget->m_serverLBox->item(current)->setText(server.host());
@@ -286,7 +301,7 @@ namespace Konversation
     {
         QPointer<ChannelDialog> dlg = new ChannelDialog(i18n("Add Channel"), this);
 
-        if(dlg->exec() == KDialog::Accepted)
+        if(dlg->exec() == QDialog::Accepted)
         {
             ChannelSettings channel = dlg->channelSettings();
             m_mainWidget->m_channelLBox->addItem(channel.name());
@@ -305,7 +320,7 @@ namespace Konversation
             QPointer<ChannelDialog> dlg = new ChannelDialog(i18n("Edit Channel"), this);
             dlg->setChannelSettings(m_channelList[current]);
 
-            if(dlg->exec() == KDialog::Accepted)
+            if(dlg->exec() == QDialog::Accepted)
             {
                 ChannelSettings channel = dlg->channelSettings();
                 m_mainWidget->m_channelLBox->item(current)->setText(channel.name());
@@ -346,7 +361,7 @@ namespace Konversation
         }
 
         m_mainWidget->m_removeChannelButton->setEnabled(channelBoxSelection.count());
-        m_mainWidget->m_changeChannelButton->setEnabled(channelBoxSelection.count());   
+        m_mainWidget->m_changeChannelButton->setEnabled(channelBoxSelection.count());
     }
 
     void ServerGroupDialog::moveChannelUp()
@@ -386,7 +401,7 @@ namespace Konversation
         QPointer<IdentityDialog> dlg = new IdentityDialog(this);
         dlg->setCurrentIdentity(m_mainWidget->m_identityCBox->currentIndex());
 
-        if(dlg->exec() == KDialog::Accepted)
+        if(dlg->exec() == QDialog::Accepted)
         {
             IdentityList identities = Preferences::identityList();
             m_mainWidget->m_identityCBox->clear();
@@ -425,22 +440,32 @@ namespace Konversation
         }
         else
         {
-            KDialog::accept();
+            QDialog::accept();
         }
     }
 
     ServerDialog::ServerDialog(const QString& title, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
     {
-        setCaption(title);
-        setButtons(Ok|Cancel);
+        setWindowTitle(title);
+        QWidget *mainWidget = new QWidget(this);
+        QVBoxLayout *mainLayout = new QVBoxLayout;
+        setLayout(mainLayout);
+        mainLayout->addWidget(mainWidget);
+        
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        m_okButton = buttonBox->button(QDialogButtonBox::Ok);
+        m_okButton->setDefault(true);
+        m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerDialog::reject);
+        mainLayout->addWidget(buttonBox);
 
         m_mainWidget = new Ui::ServerDialogUI();
-        m_mainWidget->setupUi(mainWidget());
+        m_mainWidget->setupUi(mainWidget);
         m_mainWidget->m_serverEdit->setFocus();
 
-        connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-        connect( m_mainWidget->m_serverEdit, SIGNAL(textChanged(QString)),this,SLOT(slotServerNameChanged(QString)) );
+        connect(m_okButton, &QPushButton::clicked, this, &ServerDialog::slotOk);
+        connect(m_mainWidget->m_serverEdit, &KLineEdit::textChanged, this, &ServerDialog::slotServerNameChanged);
         slotServerNameChanged( m_mainWidget->m_serverEdit->text() );
     }
 
@@ -450,7 +475,7 @@ namespace Konversation
 
     void ServerDialog::slotServerNameChanged( const QString &text )
     {
-        enableButtonOk( !text.isEmpty() );
+        m_okButton->setEnabled( !text.isEmpty() );
     }
 
     void ServerDialog::setServerSettings(const ServerSettings& server)
@@ -485,17 +510,26 @@ namespace Konversation
     }
 
     ChannelDialog::ChannelDialog(const QString& title, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
     {
-        setCaption(title);
-        setButtons(Ok|Cancel);
+        setWindowTitle(title);
+        QWidget *mainWidget = new QWidget(this);
+        QVBoxLayout *mainLayout = new QVBoxLayout;
+        setLayout(mainLayout);
+        mainLayout->addWidget(mainWidget);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        m_okButton = buttonBox->button(QDialogButtonBox::Ok);
+        m_okButton->setDefault(true);
+        m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &ChannelDialog::reject);
+        mainLayout->addWidget(buttonBox);
 
         m_mainWidget = new Ui::ChannelDialogUI();
-        m_mainWidget->setupUi(mainWidget());
+        m_mainWidget->setupUi(mainWidget);
 
         m_mainWidget->m_channelEdit->setFocus();
-        connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
-        connect(m_mainWidget->m_channelEdit, SIGNAL(textChanged(QString)),this,SLOT(slotServerNameChanged(QString)) );
+        connect(m_okButton, &QPushButton::clicked, this, &ChannelDialog::slotOk);
+        connect(m_mainWidget->m_channelEdit, &KLineEdit::textChanged, this, &ChannelDialog::slotServerNameChanged);
         slotServerNameChanged( m_mainWidget->m_channelEdit->text() );
     }
 
@@ -505,7 +539,7 @@ namespace Konversation
 
     void ChannelDialog::slotServerNameChanged( const QString &text )
     {
-        enableButtonOk( !text.isEmpty() );
+        m_okButton->setEnabled( !text.isEmpty() );
     }
 
     void ChannelDialog::setChannelSettings(const ChannelSettings& channel)
@@ -537,4 +571,4 @@ namespace Konversation
 
 }
 
-#include "servergroupdialog.moc"
+
