@@ -22,6 +22,7 @@
 
 #include <QTextDocument>
 
+#include <KLocalizedString>
 #include <KNotification>
 
 
@@ -49,29 +50,31 @@ namespace Konversation
         bool osd = Preferences::self()->oSDShowChannel() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView()));
 
+        QString eventTitle = i18nc("Notification title; see Event/message in konversation.notifyrc", "New message from %1 in %2", fromNick, chatWin->getName());
+
         if (message.isEmpty())
         {
-            KNotification::event(QLatin1String("message"), QString("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("message"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
-                konvApp->osd->show('(' + chatWin->getName() + ") <" + fromNick + '>');
+                konvApp->osd->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QLatin1Char('>'));
             }
         }
         else
         {
             QString cleanedMessage = removeIrcMarkup(message);
-            QString forKNotify = Qt::escape(cleanedMessage);
+            QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("message"), QString("&lt;%1&gt; %2").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("message"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
-                konvApp->osd->show('(' + chatWin->getName() + ") <" + fromNick + "> " + cleanedMessage);
+                konvApp->osd->show(QLatin1Char('(') + chatWin->getName() + QStringLiteral(") <") + fromNick + QStringLiteral("> ") + cleanedMessage);
             }
         }
 
@@ -93,13 +96,15 @@ namespace Konversation
             (!m_mainWindow->isActiveWindow() ||
             (chatWin != m_mainWindow->getViewContainer()->getFrontView()));
 
+        QString eventTitle = i18nc("Notification title; see Event/nick in konversation.notifyrc", "Your nick was mentioned by %1 in %2", fromNick, chatWin->getName());
+
         if (message.isEmpty())
         {
-            KNotification::event(QLatin1String("nick"), QString("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("nick"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
                 konvApp->osd->show(i18n("[HighLight] (%1) &lt;%2&gt;", chatWin->getName(), fromNick));
             }
@@ -107,13 +112,13 @@ namespace Konversation
         else
         {
             QString cleanedMessage = removeIrcMarkup(message);
-            QString forKNotify = Qt::escape(cleanedMessage);
+            QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("nick"), QString("&lt;%1&gt; %2").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("nick"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
                 konvApp->osd->show(i18n("[HighLight] (%1) &lt;%2&gt; %3", chatWin->getName(), fromNick, cleanedMessage));
             }
@@ -134,13 +139,15 @@ namespace Konversation
         bool osd = Preferences::self()->oSDShowQuery() && (!m_mainWindow->isActiveWindow() ||
             (chatWin != m_mainWindow->getViewContainer()->getFrontView()));
 
-        if (message.isEmpty())
+        QString eventTitle = i18nc("Notification title; see Event/message in konversation.notifyrc", "New query message from %1", chatWin->getName());
+
+        if (message.isEmpty()) // TODO document how this can happen, seems nonsensical
         {
-            KNotification::event(QLatin1String("queryMessage"), QString("&lt;%1&gt;").arg(fromNick), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("queryMessage"), eventTitle, QString(QStringLiteral("&lt;%1&gt;")).arg(fromNick), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
                 konvApp->osd->show(i18n("[Query] &lt;%1&gt;", fromNick));
             }
@@ -148,13 +155,13 @@ namespace Konversation
         else
         {
             QString cleanedMessage = removeIrcMarkup(message);
-            QString forKNotify = Qt::escape(cleanedMessage);
+            QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-            KNotification::event(QLatin1String("queryMessage"), QString("&lt;%1&gt; %2").arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+            KNotification::event(QLatin1String("queryMessage"), eventTitle, QString(QStringLiteral("&lt;%1&gt; %2")).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
 
             if (osd)
             {
-                Application* konvApp = static_cast<Application*>(kapp);
+                Application* konvApp = Application::instance();
 
                 konvApp->osd->show(i18n("[Query] &lt;%1&gt; %2", fromNick, cleanedMessage));
             }
@@ -190,7 +197,7 @@ namespace Konversation
         if(Preferences::self()->oSDShowChannelEvent() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
-            Application* konvApp = static_cast<Application*>(kapp);
+            Application* konvApp = Application::instance();
             konvApp->osd->show(i18n("%1 joined %2",nick, chatWin->getName()));
         }
     }
@@ -209,7 +216,7 @@ namespace Konversation
         if(Preferences::self()->oSDShowChannelEvent() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
-            Application* konvApp = static_cast<Application*>(kapp);
+            Application* konvApp = Application::instance();
             konvApp->osd->show(i18n("%1 parted %2",nick, chatWin->getName()));
         }
     }
@@ -272,7 +279,7 @@ namespace Konversation
         }
         else
         {
-            KNotification *notification = new KNotification("dcctransfer_done", m_mainWindow);
+            KNotification *notification = new KNotification(QStringLiteral("dcctransfer_done"), m_mainWindow);
             notification->setText(i18nc("%1 - filename","%1 File Transfer is complete", file));
             //notification->setPixmap( QPixmap() );
             notification->setActions(QStringList(i18nc("Opens the file from the finished dcc transfer", "Open")));
@@ -289,7 +296,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification("mode", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("mode"), m_mainWindow);
         ev->setText(i18n("%1 changed modes in %2: %3", nick, subject, change));
         ev->sendEvent();
     }
@@ -304,7 +311,7 @@ namespace Konversation
 
         startTrayNotification(chatWin);
 
-        KNotification *ev=new KNotification("query", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("query"), m_mainWindow);
         ev->setText(i18n("%1 has started a conversation (query) with you.",fromNick));
         ev->sendEvent();
     }
@@ -317,7 +324,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification("notify", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("notify"), m_mainWindow);
         ev->setText(i18n("%1 is online (%2).", nick, chatWin->getServer()->getServerName()));
         ev->sendEvent();
 
@@ -331,7 +338,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification("notify", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("notify"), m_mainWindow);
         ev->setText(i18n("%1 went offline (%2).", nick, chatWin->getServer()->getServerName()));
         ev->sendEvent();
 
@@ -345,7 +352,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification("kick", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("kick"), m_mainWindow);
         ev->setText(i18n("You are kicked by %1 from %2", nick, channel));
         ev->sendEvent();
 
@@ -359,7 +366,7 @@ namespace Konversation
         if (Preferences::self()->disableNotifyWhileAway() && chatWin->getServer() && chatWin->getServer()->isAway())
             return;
 
-        KNotification *ev=new KNotification("dccChat", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("dccChat"), m_mainWindow);
         ev->setText(i18n("%1 started a DCC chat with you", nick));
         ev->sendEvent();
 
@@ -376,17 +383,23 @@ namespace Konversation
         startTrayNotification(chatWin);
 
         QString cleanedMessage = removeIrcMarkup(message);
-        QString forKNotify = Qt::escape(cleanedMessage);
+        QString forKNotify = cleanedMessage.toHtmlEscaped();
 
-        if(fromNick.isEmpty())
-            KNotification::event(QLatin1String("highlight"), QString("(%1) *** %2").arg(chatWin->getName()).arg(forKNotify), QPixmap(), m_mainWindow);
+        if(fromNick.isEmpty()) // TODO document this one too
+        {
+            QString eventTitle = i18nc("Notification title; see Event/highlight in konversation.notifyrc", "Highlight triggered in %1", chatWin->getName());
+            KNotification::event(QLatin1String("highlight"), eventTitle, QString(QStringLiteral("(%1) *** %2")).arg(chatWin->getName()).arg(forKNotify), QPixmap(), m_mainWindow);
+        }
         else
-            KNotification::event(QLatin1String("highlight"), QString("(%1) &lt;%2&gt; %3").arg(chatWin->getName()).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+        {
+            QString eventTitle = i18nc("Notification title; see Event/highlight in konversation.notifyrc", "Highlight triggered by %2 in %1", chatWin->getName(), fromNick);
+            KNotification::event(QLatin1String("highlight"), eventTitle, QString(QStringLiteral("(%1) &lt;%2&gt; %3")).arg(chatWin->getName()).arg(fromNick).arg(forKNotify), QPixmap(), m_mainWindow);
+        }
 
         if(Preferences::self()->oSDShowOwnNick() &&
             (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
-            Application* konvApp = static_cast<Application*>(kapp);
+            Application* konvApp = Application::instance();
             // if there was no nick associated, this must be a command message, so don't try displaying
             // an empty nick in <>
             if(fromNick.isEmpty())
@@ -402,7 +415,7 @@ namespace Konversation
         if (!chatWin || !chatWin->notificationsEnabled())
             return;
 
-        KNotification *ev=new KNotification("connectionFailure", m_mainWindow);
+        KNotification *ev=new KNotification(QStringLiteral("connectionFailure"), m_mainWindow);
         ev->setText(i18n("Failed to connect to %1", server));
         ev->sendEvent();
 
@@ -421,4 +434,4 @@ namespace Konversation
 
 }
 
-#include "notificationhandler.moc"
+
