@@ -28,14 +28,15 @@
 
 #include <KBookmarkDialog>
 #include <KBookmarkManager>
-#include <KFileDialog>
+#include <QFileDialog>
 #include <KFilterProxySearchLine>
 #include <KIO/CopyJob>
-#include <KMenu>
+#include <QIcon>
+#include <KLocalizedString>
+#include <QMenu>
 #include <KMessageBox>
 #include <KToolBar>
 
-
 UrlDateItem::UrlDateItem(const QDateTime& dateTime)
 {
     setData(dateTime);
@@ -48,7 +49,7 @@ UrlDateItem::~UrlDateItem()
 QVariant UrlDateItem::data(int role) const
 {
     if (role == Qt::DisplayRole)
-        return KGlobal::locale()->formatDateTime(QStandardItem::data().toDateTime(), KLocale::ShortDate, true);
+        return QLocale().toString(QStandardItem::data().toDateTime(), QLocale::ShortFormat);
 
     return QStandardItem::data(role);
 }
@@ -92,30 +93,30 @@ UrlCatcher::UrlCatcher(QWidget* parent) : ChatWindow(parent)
 
 UrlCatcher::~UrlCatcher()
 {
-    Preferences::saveColumnState(m_urlTree, "UrlCatcher ViewSettings");
+    Preferences::saveColumnState(m_urlTree, QStringLiteral("UrlCatcher ViewSettings"));
 }
 
 void UrlCatcher::setupActions()
 {
     m_toolBar = new KToolBar(this, true, true);
-    m_contextMenu = new KMenu(this);
+    m_contextMenu = new QMenu(this);
 
     QAction* action;
 
-    action = m_toolBar->addAction(KIcon("window-new"), i18nc("open url", "&Open"), this, SLOT(openSelectedUrls()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("window-new")), i18nc("open url", "&Open"), this, SLOT(openSelectedUrls()));
     m_itemActions.append(action);
     m_contextMenu->addAction(action);
     action->setStatusTip(i18n("Open URLs in external browser."));
     action->setWhatsThis(i18n("<p>Select one or several <b>URLs</b> below, then click this button to launch the application associated with the mimetype of the URL.</p>-<p>In the <b>Settings</b>, under <b>Behavior</b> | <b>General</b>, you can specify a custom web browser for web URLs.</p>"));
     action->setEnabled(false);
 
-    action = m_toolBar->addAction(KIcon("document-save"), i18n("&Save..."), this, SLOT(saveSelectedUrls()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18n("&Save..."), this, SLOT(saveSelectedUrls()));
     m_itemActions.append(action);
     m_contextMenu->addAction(action);
     action->setStatusTip(i18n("Save selected URLs to the disk."));
     action->setEnabled(false);
 
-    action = m_toolBar->addAction(KIcon("bookmark-new"), i18n("Add Bookmark..."), this, SLOT (bookmarkSelectedUrls()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("bookmark-new")), i18n("Add Bookmark..."), this, SLOT (bookmarkSelectedUrls()));
     m_itemActions.append(action);
     m_contextMenu->addAction(action);
     action->setEnabled(false);
@@ -123,14 +124,14 @@ void UrlCatcher::setupActions()
     m_toolBar->addSeparator();
     m_contextMenu->addSeparator();
 
-    action = m_toolBar->addAction(KIcon("edit-copy"), i18nc("copy url","&Copy"), this, SLOT(copySelectedUrls()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("copy url","&Copy"), this, SLOT(copySelectedUrls()));
     m_itemActions.append(action);
     m_contextMenu->addAction(action);
     action->setStatusTip(i18n("Copy URLs to the clipboard."));
     action->setWhatsThis(i18n("Select one or several <b>URLs</b> above, then click this button to copy them to the clipboard."));
     action->setEnabled(false);
 
-    action = m_toolBar->addAction(KIcon("edit-delete"), i18nc("delete url","&Delete"), this, SLOT(deleteSelectedUrls()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("delete url","&Delete"), this, SLOT(deleteSelectedUrls()));
     m_itemActions.append(action);
     m_contextMenu->addAction(action);
     action->setWhatsThis(i18n("Select one or several <b>URLs</b> above, then click this button to delete them from the list."));
@@ -140,13 +141,13 @@ void UrlCatcher::setupActions()
     m_toolBar->addSeparator();
     m_contextMenu->addSeparator();
 
-    action = m_toolBar->addAction(KIcon("document-save"), i18nc("save url list", "&Save List..."), this, SLOT(saveUrlModel()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("save url list", "&Save List..."), this, SLOT(saveUrlModel()));
     m_listActions.append(action);
     action->setStatusTip(i18n("Save list."));
     action->setWhatsThis(i18n("Click to save the entire list to a file."));
     action->setEnabled(false);
 
-    action = m_toolBar->addAction(KIcon("edit-clear-list"), i18nc("clear url list","&Clear List"), this, SLOT(clearUrlModel()));
+    action = m_toolBar->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-list")), i18nc("clear url list","&Clear List"), this, SLOT(clearUrlModel()));
     m_listActions.append(action);
     action->setStatusTip(i18n("Clear list."));
     action->setWhatsThis(i18n("Click to erase the entire list."));
@@ -163,15 +164,15 @@ void UrlCatcher::setupUrlTree()
     m_urlTree->setWhatsThis(i18n("List of Uniform Resource Locators mentioned in any of the Konversation windows during this session."));
     m_urlTree->setContextMenuPolicy(Qt::CustomContextMenu);
     m_urlTree->setSortingEnabled(true);
-    m_urlTree->header()->setMovable(false);
+    m_urlTree->header()->setSectionsMovable(false);
     m_urlTree->header()->setSortIndicatorShown(true);
     m_urlTree->setAllColumnsShowFocus(true);
     m_urlTree->setSelectionMode(QAbstractItemView::ExtendedSelection);
     m_urlTree->setRootIsDecorated(false);
-    connect(m_urlTree, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(openContextMenu(QPoint)));
-    connect(m_urlTree, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(openUrl(QModelIndex)));
+    connect(m_urlTree, &QTreeView::customContextMenuRequested, this, &UrlCatcher::openContextMenu);
+    connect(m_urlTree, &QTreeView::doubleClicked, this, &UrlCatcher::openUrl);
 
-    Application* konvApp = static_cast<Application*>(kapp);
+    Application* konvApp = Application::instance();
     QStandardItemModel* urlModel = konvApp->getUrlModel();
     QStandardItem* item = new QStandardItem(i18n("From"));
     urlModel->setHorizontalHeaderItem(0, item);
@@ -179,8 +180,8 @@ void UrlCatcher::setupUrlTree()
     urlModel->setHorizontalHeaderItem(1, item);
     item = new QStandardItem(i18n("Date"));
     urlModel->setHorizontalHeaderItem(2, item);
-    connect(urlModel, SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(updateListActionStates()));
-    connect(urlModel, SIGNAL(rowsRemoved(QModelIndex,int,int)), this, SLOT(updateListActionStates()));
+    connect(urlModel, &QStandardItemModel::rowsInserted, this, &UrlCatcher::updateListActionStates);
+    connect(urlModel, &QStandardItemModel::rowsRemoved, this, &UrlCatcher::updateListActionStates);
 
     UrlSortFilterProxyModel* proxyModel = new UrlSortFilterProxyModel(this);
     proxyModel->setSourceModel(urlModel);
@@ -191,11 +192,10 @@ void UrlCatcher::setupUrlTree()
     m_urlTree->setModel(proxyModel);
     connect(m_urlTree->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
         this, SLOT(updateItemActionStates()));
-    connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this, SLOT(checkLocaleChanged(int)));
 
     searchLine->setProxy(proxyModel);
 
-    Preferences::restoreColumnState(m_urlTree, "UrlCatcher ViewSettings", 2, Qt::DescendingOrder);
+    Preferences::restoreColumnState(m_urlTree, QStringLiteral("UrlCatcher ViewSettings"), 2, Qt::DescendingOrder);
 }
 
 void UrlCatcher::updateItemActionStates()
@@ -207,7 +207,7 @@ void UrlCatcher::updateItemActionStates()
 
 void UrlCatcher::updateListActionStates()
 {
-    Application* konvApp = static_cast<Application*>(kapp);
+    Application* konvApp = Application::instance();
     bool enable = konvApp->getUrlModel()->rowCount();
 
     foreach(QAction* action, m_listActions) action->setEnabled(enable);
@@ -269,8 +269,8 @@ void UrlCatcher::saveSelectedUrls()
     {
         if (index.isValid())
         {
-            KUrl url(index.data().toString());
-            KUrl targetUrl = KFileDialog::getSaveUrl(url.fileName(KUrl::ObeyTrailingSlash), QString(), this, i18n("Save link as"));
+            QUrl url(index.data().toString());
+            QUrl targetUrl = QFileDialog::getSaveFileUrl(this, i18n("Save link as"), QUrl::fromLocalFile(url.fileName()));
 
             if (targetUrl.isEmpty() || !targetUrl.isValid())
                 continue;
@@ -289,10 +289,10 @@ void UrlCatcher::bookmarkSelectedUrls()
 
     if (selectedIndexes.count() > 1)
     {
-        QList<QPair<QString, QString> > bookmarks;
+        QList<KBookmarkOwner::FutureBookmark> bookmarks;
 
         foreach(const QModelIndex& index, selectedIndexes)
-            bookmarks << QPair<QString, QString>(index.data().toString(), index.data().toString());
+            bookmarks << KBookmarkOwner::FutureBookmark(index.data().toString(), QUrl(index.data().toString()), QString());
 
         dialog->addBookmarks(bookmarks, i18n("New"));
     }
@@ -300,7 +300,7 @@ void UrlCatcher::bookmarkSelectedUrls()
     {
         QString url = selectedIndexes.first().data().toString();
 
-        dialog->addBookmark(url, url);
+        dialog->addBookmark(url, QUrl(url), QString());
     }
 
     delete dialog;
@@ -316,7 +316,7 @@ void UrlCatcher::copySelectedUrls()
         if (index.isValid()) urls << index.data().toString();
 
     QClipboard* clipboard = qApp->clipboard();
-    clipboard->setText(urls.join("\n"), QClipboard::Clipboard);
+    clipboard->setText(urls.join(QStringLiteral("\n")), QClipboard::Clipboard);
 }
 
 void UrlCatcher::deleteSelectedUrls()
@@ -326,7 +326,7 @@ void UrlCatcher::deleteSelectedUrls()
     foreach(const QPersistentModelIndex& index, m_urlTree->selectionModel()->selectedIndexes())
         selectedIndices << index;
 
-    Application* konvApp = static_cast<Application*>(kapp);
+    Application* konvApp = Application::instance();
 
     foreach(const QPersistentModelIndex& index, selectedIndices)
         if (index.isValid()) konvApp->getUrlModel()->removeRow(index.row());
@@ -334,12 +334,12 @@ void UrlCatcher::deleteSelectedUrls()
 
 void UrlCatcher::saveUrlModel()
 {
-    QString target = KFileDialog::getSaveFileName(QString(), QString(), this,
-        i18n("Save URL List"), KFileDialog::ConfirmOverwrite);
+    QString target = QFileDialog::getSaveFileName(this,
+        i18n("Save URL List"));
 
     if (!target.isEmpty())
     {
-        Application* konvApp = static_cast<Application*>(kapp);
+        Application* konvApp = Application::instance();
         QStandardItemModel* urlModel = konvApp->getUrlModel();
 
         int nickColumnWidth = 0;
@@ -363,13 +363,13 @@ void UrlCatcher::saveUrlModel()
         QTextStream stream(&file);
 
         stream << i18n("Konversation URL List: %1\n\n",
-            KGlobal::locale()->formatDateTime(QDateTime::currentDateTime(), KLocale::LongDate, true));
+            QLocale().toString(QDateTime::currentDateTime(), QLocale::LongFormat));
 
         for (int r = 0; r < rows; r++)
         {
-            QString line = index.sibling(r, 0).data().toString().leftJustified(nickColumnWidth, ' ');
+            QString line = index.sibling(r, 0).data().toString().leftJustified(nickColumnWidth, QLatin1Char(' '));
             line.append(index.sibling(r, 1).data().toString());
-            line.append('\n');
+            line.append(QLatin1Char('\n'));
 
             stream << line;
         }
@@ -380,26 +380,25 @@ void UrlCatcher::saveUrlModel()
 
 void UrlCatcher::clearUrlModel()
 {
-    Application* konvApp = static_cast<Application*>(kapp);
+    Application* konvApp = Application::instance();
     QStandardItemModel* urlModel = konvApp->getUrlModel();
 
     urlModel->removeRows(0, urlModel->rowCount());
 }
 
-void UrlCatcher::checkLocaleChanged(int category)
-{
-#if KDE_IS_VERSION(4,8,1)
-    if (category != KGlobalSettings::SETTINGS_LOCALE)
-        return;
-
-    Application* konvApp = static_cast<Application*>(kapp);
-    QStandardItemModel* urlModel = konvApp->getUrlModel();
-
-    m_urlTree->dataChanged(urlModel->index(0, 0), urlModel->index(urlModel->rowCount() - 1, 2));
-#endif
-}
-
 void UrlCatcher::childAdjustFocus()
 {
     m_urlTree->setFocus();
 }
+
+bool UrlCatcher::event(QEvent* event)
+{
+    if (event->type() == QEvent::LocaleChange) {
+        Application* konvApp = Application::instance();
+        QStandardItemModel* urlModel = konvApp->getUrlModel();
+
+        m_urlTree->dataChanged(urlModel->index(0, 0), urlModel->index(urlModel->rowCount() - 1, 2));
+    }
+
+    return ChatWindow::event(event);
+}
